Module buffer
mtp_
mount
0.4.0
Module buffer
Module Items
Structs
In crate mtp_
mount
mtp_mount
Module
buffer
Structs

File
Buffer
Per-file write buffer backed by an unlinked temp file in the spool dir.
Write
Buffer
Manages in-progress file writes, mapping file handles to their buffers.